"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignalEmitter = void 0;
const analytics_generic_utils_1 = require("@segment/analytics-generic-utils");
const logger_1 = require("../../lib/logger");
const logSignal = (signal) => {
    logger_1.logger.info('New signal:', signal.type, signal.data, ...(signal.type === 'interaction' && 'change' in signal.data
        ? ['change:', JSON.stringify(signal.data.change, null, 2)]
        : []));
};
class SignalEmitter {
    constructor() {
        this.emitter = new analytics_generic_utils_1.Emitter();
        this.listeners = new Set();
    }
    emit(signal) {
        logSignal(signal);
        this.emitter.emit('add', signal);
    }
    subscribe(listener) {
        // Prevent duplicate subscriptions
        if (!this.listeners.has(listener)) {
            logger_1.logger.debug('subscribed');
            this.listeners.add(listener);
        }
        this.emitter.on('add', listener);
    }
    unsubscribe(listener) {
        this.listeners.delete(listener);
        logger_1.logger.debug('unsubscribed');
        this.emitter.off('add', listener);
    }
    once(listener) {
        this.emitter.once('add', listener);
    }
}
exports.SignalEmitter = SignalEmitter;
//# sourceMappingURL=index.js.map