"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignalsPlugin = void 0;
const signals_1 = require("../core/signals");
const logger_1 = require("../lib/logger");
const assert_browser_env_1 = require("../lib/assert-browser-env");
const version_1 = require("../generated/version");
class SignalsPlugin {
    constructor(settings = {}) {
        this.type = 'utility';
        this.name = 'SignalsPlugin';
        this.version = version_1.version;
        (0, assert_browser_env_1.assertBrowserEnv)();
        // assign to window for debugging purposes
        Object.assign(window, { SegmentSignalsPlugin: this });
        if (settings.enableDebugLogging) {
            logger_1.logger.enableLogging('debug');
        }
        logger_1.logger.debug(`SignalsPlugin v${version_1.version} initializing`, {
            settings,
        });
        this.signals = new signals_1.Signals({
            disableSignalsRedaction: settings.disableSignalsRedaction,
            enableSignalsIngestion: settings.enableSignalsIngestion,
            flushAt: settings.flushAt,
            flushInterval: settings.flushInterval,
            functionHost: settings.functionHost,
            apiHost: settings.apiHost,
            maxBufferSize: settings.maxBufferSize,
            processSignal: typeof settings.processSignal === 'function'
                ? settings.processSignal.toString()
                : settings.processSignal,
            networkSignalsAllowSameDomain: settings.networkSignalsAllowSameDomain,
            networkSignalsAllowList: settings.networkSignalsAllowList,
            networkSignalsDisallowList: settings.networkSignalsDisallowList,
            signalStorage: settings.signalStorage,
            signalStorageType: settings.signalStorageType,
        });
    }
    isLoaded() {
        return true;
    }
    async load(_ctx, analytics) {
        try {
            await this.signals.start(analytics);
            logger_1.logger.debug('SignalsPlugin loaded');
        }
        catch (err) {
            console.error(err);
        }
    }
    stop() {
        return this.signals.stop();
    }
    onSignal(cb) {
        this.signals.signalEmitter.subscribe(cb);
        return this;
    }
    addSignal(signal) {
        this.signals.signalEmitter.emit(signal);
        return this;
    }
    /**
     * Enable redaction and disable ingestion of signals. Also, logs signals to the console.
     */
    debug(...args) {
        this.signals.debug(...args);
    }
}
exports.SignalsPlugin = SignalsPlugin;
//# sourceMappingURL=signals-plugin.js.map