import { Emitter } from '@segment/analytics-generic-utils';
import { logger } from '../../lib/logger';
const logSignal = (signal) => {
    logger.info('New signal:', signal.type, signal.data, ...(signal.type === 'interaction' && 'change' in signal.data
        ? ['change:', JSON.stringify(signal.data.change, null, 2)]
        : []));
};
export class SignalEmitter {
    constructor() {
        this.emitter = new Emitter();
        this.listeners = new Set();
    }
    emit(signal) {
        logSignal(signal);
        this.emitter.emit('add', signal);
    }
    subscribe(listener) {
        // Prevent duplicate subscriptions
        if (!this.listeners.has(listener)) {
            logger.debug('subscribed');
            this.listeners.add(listener);
        }
        this.emitter.on('add', listener);
    }
    unsubscribe(listener) {
        this.listeners.delete(listener);
        logger.debug('unsubscribed');
        this.emitter.off('add', listener);
    }
    once(listener) {
        this.emitter.once('add', listener);
    }
}
//# sourceMappingURL=index.js.map