import { SignalEmitter } from '../../emitter';
import { SignalGenerator } from '../types';
import type { ParsedAttributes } from '@segment/analytics-signals-runtime';
interface Label {
    textContent: string;
    id: string;
    attributes: ParsedAttributes;
}
interface ParsedElementBase {
    /**
     * The attributes of the element -- this is a key-value object of the attributes of the element
     */
    attributes: ParsedAttributes;
    classList: string[];
    id: string;
    /**
     * The labels associated with this element -- either from the `labels` property or from the `aria-labelledby` attribute
     */
    labels?: Label[];
    /**
     * The first label associated with this element -- either from the `labels` property or from the `aria-labelledby` attribute
     */
    label?: Label;
    name?: string;
    nodeName: string;
    tagName: string;
    title: string;
    type?: string;
    /**
     * The value of the element -- for inputs, this is the value of the input, for selects, this is the value of the selected option
     */
    value?: string;
    /**
     * The value content of the element -- this is the value content of the element, stripped of newlines, tabs, and multiple spaces
     */
    textContent?: string;
    /**
     * The inner value of the element -- this is the value content of the element, stripped of newlines, tabs, and multiple spaces
     */
    innerText?: string;
    /**
     * The element referenced by the `aria-describedby` attribute
     */
    describedBy?: Label;
}
interface ParsedSelectElement extends ParsedElementBase {
    selectedOptions: {
        label: string;
        value: string;
    }[];
    selectedIndex: number;
}
interface ParsedInputElement extends ParsedElementBase {
    checked: boolean;
}
interface ParsedMediaElement extends ParsedElementBase {
    currentSrc?: string;
    currentTime?: number;
    duration: number;
    ended: boolean;
    muted: boolean;
    paused: boolean;
    playbackRate: number;
    readyState?: number;
    src?: string;
    volume?: number;
}
interface ParsedHTMLFormElement extends ParsedElementBase {
    formData: Record<string, string>;
    innerText: never;
    textContent: never;
}
type AnyParsedElement = ParsedHTMLFormElement | ParsedSelectElement | ParsedInputElement | ParsedMediaElement | ParsedElementBase;
export declare const parseElement: (el: HTMLElement) => AnyParsedElement;
export declare class ClickSignalsGenerator implements SignalGenerator {
    id: string;
    register(emitter: SignalEmitter): () => void;
    private getClosestClickableElement;
}
export declare class FormSubmitGenerator implements SignalGenerator {
    id: string;
    register(emitter: SignalEmitter): () => void;
}
export declare const shouldIgnoreElement: (el: HTMLElement) => boolean;
export declare class OnNavigationEventGenerator implements SignalGenerator {
    id: string;
    register(emitter: SignalEmitter): () => void;
    private createCommonFields;
}
export {};
//# sourceMappingURL=dom-gen.d.ts.map