import { JSONValue } from '@segment/analytics-next';
export type HTTPMethod = 'GET' | 'POST' | 'PUT' | 'DELETE' | 'PATCH' | 'HEAD' | 'OPTIONS';
export interface NetworkInterceptorRequest {
    url: string;
    method: HTTPMethod;
    contentType: string | undefined;
    body: string | undefined;
    headers: Headers;
    id: string;
}
export interface NetworkInterceptorResponse {
    url: string;
    status: number;
    ok: boolean;
    statusText: string;
    headers: Headers;
    body: () => Promise<JSONValue>;
    initiator: 'fetch' | 'xhr';
    responseType: XMLHttpRequestResponseType | undefined;
    req: {
        id: string;
    };
}
/**
 * Taken from https://developer.mozilla.org/en-US/docs/Web/API/XMLHttpRequest/response
 */
export interface NetworkResponseHandler {
    (rs: NetworkInterceptorResponse): void;
}
export interface NetworkRequestHandler {
    (rq: NetworkInterceptorRequest): void;
}
/**
 * NetworkInterceptor class to intercept network requests and responses
 */
export declare class NetworkInterceptor {
    addInterceptors(onRequest: NetworkRequestHandler, onResponse: NetworkResponseHandler): void;
    private addFetchInterceptor;
    private addXhrInterceptor;
    cleanup(): void;
}
//# sourceMappingURL=network-interceptor.d.ts.map