import { SignalEmitter } from '../emitter';
import { SignalGenerator, SignalGeneratorClass } from '../signal-generators/types';
import { Signal } from '@segment/analytics-signals-runtime';
import { AnyAnalytics } from '../../types';
import { SignalsSettingsConfig } from './settings';
import { LogLevelOptions } from '../debug-mode';
interface ISignals {
    start(analytics: AnyAnalytics): Promise<void>;
    stop(): void;
    clearStorage(): void;
    registerGenerator(generators: (SignalGeneratorClass | SignalGenerator)[]): Promise<void>;
}
export type SignalsPublicEmitterContract = {
    signal: [Signal];
};
export declare class Signals implements ISignals {
    private buffer;
    private preStartBuffer;
    signalEmitter: SignalEmitter;
    private cleanup;
    private signalsClient;
    private globalSettings;
    constructor(settingsConfig?: SignalsSettingsConfig);
    private addToPreStartBuffer;
    /**
     * Flush/process any signals that were emitted before the start method was called.
     */
    private flushPreStartBuffer;
    /**
     * Does the following:
     * - Sends any queued signals to the server.
     * - Augments the analytics client to transform events -> signals
     * - Registers custom signal generators.
     */
    start(analytics: AnyAnalytics): Promise<void>;
    stop(): void;
    clearStorage(): void;
    /**
     * Disable redaction, ingestion of signals, and other logging.
     */
    debug(boolean?: boolean, logLevel?: LogLevelOptions): void;
    /**
     * Register custom signal generators to emit signals.
     */
    registerGenerator(generators: (SignalGeneratorClass | SignalGenerator)[]): Promise<void>;
}
export {};
//# sourceMappingURL=signals.d.ts.map